Index: ash/display/display_layout_store.h |
diff --git a/ash/display/display_layout_store.h b/ash/display/display_layout_store.h |
index a9675371269867c1f2e354522c4680cb21f1c1dc..6841ea906aa5f8057d0f6b408be2cde03a1a49d1 100644 |
--- a/ash/display/display_layout_store.h |
+++ b/ash/display/display_layout_store.h |
@@ -37,11 +37,12 @@ class ASH_EXPORT DisplayLayoutStore { |
DisplayLayout ComputeDisplayLayoutForDisplayIdPair( |
const DisplayIdPair& display_pair); |
// Update the mirrored flag in the display layout for |
// |display_pair|. This creates new display layout if no layout is |
// registered for |display_pair|. |
- void UpdateMirrorStatus(const DisplayIdPair& display_pair, |
- bool mirrored); |
+ void UpdateMultiDisplayState(const DisplayIdPair& display_pair, |
+ bool mirrored, |
+ bool default_unified); |
// Update the |primary_id| in the display layout for |
// |display_pair|. This creates new display layout if no layout is |
@@ -37,11 +37,12 @@ class ASH_EXPORT DisplayLayoutStore { |
DisplayLayout ComputeDisplayLayoutForDisplayIdPair( |
const DisplayIdPair& display_pair); |
- // Update the mirrored flag in the display layout for |
+ // Update the multi display state in the display layout for |
// |display_pair|. This creates new display layout if no layout is |
// registered for |display_pair|. |